@@ -1,9 +1,11 @@
 data("anesthesia")
 
-ds_fit <- rater(anesthesia, dawid_skene(), iter = 200, chains = 1)
-hds_fit <- rater(anesthesia, hier_dawid_skene(), iter = 200, chains = 1)
+ds_fit <- rater(anesthesia, dawid_skene(), iter = 200, chains = 1,
+                verbose = FALSE)
+hds_fit <- rater(anesthesia, hier_dawid_skene(), iter = 200, chains = 1,
+                 verbose = FALSE)
 ccds_fit <- rater(anesthesia, class_conditional_dawid_skene(), iter = 200,
-                  chains = 1)
+                  chains = 1, verbose = FALSE, seed = 42)
 
 ds_fit_optim <- rater(anesthesia, dawid_skene(), method = "optim")
 hds_fit_optim <- rater(anesthesia, hier_dawid_skene(), method = "optim")
@@ -11,7 +13,7 @@ ccds_fit_optim <- rater(anesthesia, class_conditional_dawid_skene(),
                         method = "optim")
 
 ds_fit_grouped <- rater(caries, dawid_skene(), data_format = "grouped",
-                        iter = 200, chains = 1)
+                        iter = 200, chains = 1, verbose = FALSE)
 
 ds_fit_grouped_optim <- rater(caries, dawid_skene(), method = "optim",
                               data_format = "grouped")
